import { pJSShapeType, pJSMoveDirection, pJSOutMode, pJSInteractivityDetect, pJSHoverMode, pJSClickMode } from "./pjsenums";
import { pJSContainer } from "./pjscontainer";
declare global {
    interface Window {
        requestAnimFrame: (callback: FrameRequestCallback) => number;
        mozRequestAnimationFrame: (callback: FrameRequestCallback) => number;
        oRequestAnimationFrame: (callback: FrameRequestCallback) => number;
        msRequestAnimationFrame: (callback: FrameRequestCallback) => number;
        cancelRequestAnimFrame: (handle: number) => void;
        webkitCancelRequestAnimationFrame: (handle: number) => void;
        mozCancelRequestAnimationFrame: (handle: number) => void;
        oCancelRequestAnimationFrame: (handle: number) => void;
        msCancelRequestAnimationFrame: (handle: number) => void;
        particlesJS: any;
        pJSDom: () => pJSContainer[];
    }
}
export interface pJSContainerInteractivity {
    el?: HTMLElement | Window | Node | null;
    status?: string;
    mouse: pJSMouseData;
}
export interface pJSOptions {
    particles: {
        number: {
            value: number;
            density: {
                enable: boolean;
                value_area: number;
            };
        };
        color: {
            value: string | pJSColor | string[];
        };
        shape: pJSShape;
        opacity: {
            value: number;
            random: boolean;
            anim: {
                enable: boolean;
                speed: number;
                opacity_min: number;
                sync: boolean;
            };
        };
        size: {
            value: number;
            random: boolean;
            anim: {
                enable: boolean;
                speed: number;
                size_min: number;
                sync: boolean;
            };
        };
        line_linked: {
            enable: boolean;
            distance: number;
            color: string;
            opacity: number;
            width: number;
            color_rgb?: pJSRgb | null;
        };
        move: {
            enable: boolean;
            speed: number;
            direction: pJSMoveDirection;
            random: boolean;
            straight: boolean;
            out_mode: pJSOutMode;
            bounce: boolean;
            attract: {
                enable: boolean;
                rotateX: number;
                rotateY: number;
            };
        };
    };
    interactivity: {
        detect_on: pJSInteractivityDetect;
        events: {
            onhover: {
                enable: boolean;
                mode: pJSHoverMode | pJSHoverMode[];
                parallax: {
                    enable: boolean;
                    force: number;
                    smooth: number;
                };
            };
            onclick: {
                enable: boolean;
                mode: pJSClickMode | pJSClickMode[];
            };
            resize: boolean;
        };
        modes: {
            grab: {
                distance: number;
                line_linked: {
                    opacity: number;
                };
            };
            bubble: {
                distance: number;
                size: number;
                duration: number;
                opacity: number;
            };
            repulse: {
                distance: number;
                duration: number;
            };
            push: {
                particles_nb: number;
            };
            remove: {
                particles_nb: number;
            };
        };
    };
    retina_detect: boolean;
    fps_limit: number;
}
export interface pJSShape {
    type: pJSShapeType | pJSShapeType[];
    stroke: {
        width: number;
        color: string;
    };
    polygon: {
        nb_sides: number;
    };
    character: {
        value: string | string[];
        font: string;
        style?: string;
        weight: string;
    };
    image: {
        src: string;
        width: number;
        height: number;
        replace_color: boolean;
    };
}
export interface pJSColor {
    rgb?: pJSRgb | null;
    hsl?: pJSHsl | null;
}
export interface pJSRgb {
    r: number;
    g: number;
    b: number;
}
export interface pJSHsl {
    h: number;
    s: number;
    l: number;
}
export interface pJSParticleImage {
    src: string;
    ratio: number;
    obj?: HTMLImageElement;
    loaded?: boolean;
    replace_color: boolean;
}
export interface pJSCoordinates {
    x: number;
    y: number;
}
export interface pJSMouseData {
    click_pos_x?: number | null;
    click_pos_y?: number | null;
    pos_x?: number | null;
    pos_y?: number | null;
    click_time?: number;
}
export interface pJSSvg {
    source?: string;
    count: number;
}
export interface pJSImg {
    type?: string;
    obj?: HTMLImageElement;
    error?: boolean;
}
export interface pJSBubble {
    clicking?: boolean;
    duration_end?: boolean;
}
export interface pJSRepulse {
    finish?: boolean;
    count?: number;
    clicking?: boolean;
}
